#!/bin/bash

#**********************************************************************
# TASK: submit requests using curl: HANDLE redirects and refresh url. 
# Iterate over mutation file and write/append result urls to a file
# Mutation file must have one mutation (format A1B) per line
# Requirements
# input: mutation list (format: A1B), complex struc: (pdb format)
    # mutation: outFile from step0, one unique mutation/line, no chain ID
    	# path: "Data/<drug>/input/processed/<filename>"
    # structure: pdb file of drug-target complex
    	# path: "Data/<drug>/input/structure/<filename>"
# output: should be n urls (n=no. of unique mutations in file)
	# path: "Data/<drug>/input/processed/<filename>"

# NOTE: these are just result urls, not actual values for results
#**********************************************************************
############# specify variables for input and output paths and filenames
homedir="${HOME}"
#echo Home directory is ${homedir}
basedir="/git/Data/pyrazinamide/input"

# input
inpath_mut="/processed"
in_filename_mut="/pnca_mis_SNPs_v2_unique.csv"
infile_mut="${homedir}${basedir}${inpath_mut}${in_filename_mut}"
echo Input Mut filename: ${infile_mut}

inpath_struc="/structure"
in_filename_struc="/complex1_no_water.pdb"
infile_struc="${homedir}${basedir}${inpath_struc}${in_filename_struc}"
echo Input Struc filename: ${infile_struc}

# output
outpath="/processed"
out_filename="/complex1_result_url.txt"
outfile="${homedir}${basedir}${outpath}${out_filename}"
#echo Output filename: ${outfile}
################## end of variable assignment for input and output files

# iterate over mutation file (infile_mut); line by line and 
# submit query using curl
# some useful messages
echo -n -e "Processing $(wc -l < ${infile_mut}) entries from ${infile_mut}\n"
COUNT=0
while read -r line; do
((COUNT++))
mutation="${line}"
#    echo "${mutation}"
#pdb='../Data/complex1_no_water.pdb'
pdb="${infile_struc}"
mutation="${mutation}"
chain="A"
lig_id="PZA"
affin_wt="0.99"
host="http://biosig.unimelb.edu.au"
call_url="/mcsm_lig/prediction"

#=========================================
##html field_names names required for curl
##complex_field:wild=@
##mutation_field:mutation=@
##chain_field:chain=@
##ligand_field:lig_id@
##energy_field:affin_wt
#=========================================
refresh_url=$(curl -L \
     -sS \
     -F "wild=@${pdb}" \
     -F "mutation=${mutation}" \
     -F "chain=${chain}" \
     -F "lig_id=${lig_id}" \
     -F "affin_wt=${affin_wt}" \
     ${host}${call_url} | grep "http-equiv")

#echo Refresh URL: $refresh_url
#echo Host+Refresh: ${host}${refresh_url}

# use regex to extract the relevant bit from the refresh url
# regex:sed -r 's/.*(\/mcsm.*)".*$/\1/g'

# Now build: result url using host and refresh url and write the urls to a file 
result_url=$(echo $refresh_url | sed -r 's/.*(\/mcsm.*)".*$/\1/g')
sleep 10

echo -e "${mutation} : processing entry ${COUNT}/$(wc -l < ${infile_mut})..."

# create output file with the added number of muts from file
# after much thought, bad idea as less generic!
#echo -e "${host}${result_url}" >> ../Results/$(wc -l < ${filename})_complex1_result_url.txt
echo -e "${host}${result_url}" >> ${outfile}
#echo -n '.'
done < "${infile_mut}"

#FIXME: stop executing if error else these echo statements are misleading!
echo
echo Output filename: ${outfile}
echo
echo Number of urls saved: $(wc -l < ${infile_mut})
echo
echo "Processing Complete"

# end of submitting query, receiving result url and storing results url in a file

