##################
# load libraries
 library(compare)
##################

getwd()

#=======================================================
# TASK:read cleaned data and perform rescaling
  # of DUET stability scores
  # of Pred affinity
# compare scaling methods with plots

# Requirements:
# input: R script, step3c_results_cleaning.R
  # path: Data/<drug>/input/processed/<filename>"
# output: NO output as the next scripts refers to this
# for yet more processing
# output normalised file
#=======================================================

# specify variables for input and output paths and filenames
homedir = "~"
currdir = "/git/LSHTM_analysis/mcsm_analysis/pyrazinamide/scripts/mcsm"
in_filename = "/step3c_results_cleaning.R"
infile = paste0(homedir, currdir, in_filename)
print(paste0("Input file is:", infile))

# output file
basedir = "/git/Data/pyrazinamide/input"
outpath = "/processed"
out_filename = "/mcsm_complex1_normalised.csv"
outfile = paste0(homedir, basedir, outpath, out_filename)
print(paste0("Output file is:", outfile))

####################
#### read file #####: this will be the output of my R script that cleans the data columns
####################
source(infile)

#This will outut two dataframes:
# data: unclean data: 10 cols
# df : cleaned df: 13 cols
# you can remove data if you want as you will not need it
rm(data)

colnames(df)

#===================
#3a: PredAffLog
#===================
n = which(colnames(df) == "PredAffLog"); n
group = which(colnames(df) == "Lig_outcome"); group 

#===================================================
# order according to PredAffLog values
#===================================================
# This is because this makes it easier to see the results of rescaling for debugging
head(df$PredAffLog)

# ORDER BY PredAff scrores: negative  values at the top and positive at the bottoom
df = df[order(df$PredAffLog),] 
head(df$PredAffLog)

# sanity checks
head(df[,n]) # all negatives
tail(df[,n]) # all positives

# sanity checks
mean(df[,n])
#-0.9526746

tapply(df[,n], df[,group], mean)

#===========================
# Same as above: in 2 steps
#===========================

# find range of your data
my_min = min(df[,n]); my_min #
my_max = max(df[,n]); my_max #

#===============================================
# WITHIN GROUP rescaling 2: method "ratio"
# create column to store the rescaled values
# Rescaling separately (Less dangerous) 
#       =====> chosen one: preserves sign
#===============================================
df$ratioPredAff = ifelse(df[,n] < 0
                      , df[,n]/abs(my_min)
                      , df[,n]/my_max
                      )# 14 cols
# sanity checks
head(df$ratioPredAff)
tail(df$ratioPredAff)

min(df$ratioPredAff); max(df$ratioPredAff)

tapply(df$ratioPredAff, df$Lig_outcome, min)

tapply(df$ratioPredAff, df$Lig_outcome, max)

# should be the same as below 
sum(df$ratioPredAff < 0); sum(df$ratioPredAff > 0)

table(df$Lig_outcome)

#===============================================
# Hist and density plots to compare the rescaling 
# methods: Base R
#===============================================
# uncomment as necessary
my_title = "Ligand_stability"
# my_title = colnames(df[n])

# Set the margin on all sides
par(oma = c(3,2,3,0)
    , mar = c(1,3,5,2)
    , mfrow = c(2,2))

hist(df[,n]
     , xlab = ""
     , main = "Raw values"
)

hist(df$ratioPredAff
     , xlab = ""
     , main = "ratio rescaling"
)

# Plot density plots underneath
plot(density( df[,n] )
     , main = "Raw values"
)

plot(density( df$ratioPredAff )
     , main = "ratio rescaling"
)

# titles
mtext(text = "Frequency"
       , side = 2
       , line = 0
       , outer = TRUE)

mtext(text = my_title
      , side = 3
      , line = 0
      , outer = TRUE)


#clear variables 
rm(my_min, my_max, my_title, n, group)

#===================
# 3b: DUET stability
#===================
dim(df) # 14 cols

n = which(colnames(df) == "DUETStability_Kcalpermol"); n # 10
group = which(colnames(df) == "DUET_outcome"); group #12

#===================================================
# order according to DUET scores
#===================================================
# This is because this makes it easier to see the results of rescaling for debugging
head(df$DUETStability_Kcalpermol)

# ORDER BY DUET scores: negative values at the top and positive at the bottom
df = df[order(df$DUETStability_Kcalpermol),] 

# sanity checks
head(df[,n]) # negatives
tail(df[,n]) # positives

# sanity checks
mean(df[,n])

tapply(df[,n], df[,group], mean)

#===============================================
# WITHIN GROUP rescaling 2: method "ratio"
# create column to store the rescaled values
# Rescaling separately (Less dangerous) 
#       =====> chosen one: preserves sign
#===============================================
# find range of your data
my_min = min(df[,n]); my_min 
my_max = max(df[,n]); my_max

df$ratioDUET = ifelse(df[,n] < 0
                      , df[,n]/abs(my_min)
                      , df[,n]/my_max
                    ) # 15 cols
# sanity check
head(df$ratioDUET)
tail(df$ratioDUET)

min(df$ratioDUET); max(df$ratioDUET)

# sanity checks
tapply(df$ratioDUET, df$DUET_outcome, min)

tapply(df$ratioDUET, df$DUET_outcome, max)

# should be the same as below (267 and 42)
sum(df$ratioDUET < 0); sum(df$ratioDUET > 0)

table(df$DUET_outcome)

#===============================================
# Hist and density plots to compare the rescaling 
# methods: Base R
#===============================================
# uncomment as necessary
my_title = "DUET_stability"
#my_title = colnames(df[n])

# Set the margin on all sides
par(oma = c(3,2,3,0)
    , mar = c(1,3,5,2)
    , mfrow = c(2,2))

hist(df[,n]
     , xlab = ""
     , main = "Raw values"
)

hist(df$ratioDUET
     , xlab = ""
     , main = "ratio rescaling"
)

# Plot density plots underneath
plot(density( df[,n] )
     , main = "Raw values"
)

plot(density( df$ratioDUET )
     , main = "ratio rescaling"
)

# graph titles
mtext(text = "Frequency"
      , side = 2
      , line = 0
      , outer = TRUE)

mtext(text = my_title
      , side = 3
      , line = 0
      , outer = TRUE)

# reorder by column name
#data <- data[c("A", "B", "C")]
colnames(df)
df2 = df[c("X", "Mutationinformation",  "WildPos", "Position"
           , "Wild_type", "Mutant_type"
           , "DUETStability_Kcalpermol", "DUET_outcome"
           , "Dis_lig_Ang", "PredAffLog", "Lig_outcome"
           , "ratioDUET", "ratioPredAff"
           , "LigandID","Chain")]

# sanity check
# should be True
#compare(df, df2, allowAll = T)
compare(df, df2, ignoreColOrder = T)
#TRUE 
#reordered columns

#===================
# write output as csv file
#===================
#write.csv(df, "../Data/mcsm_complex1_normalised.csv", row.names = FALSE)
write.csv(df2, outfile, row.names = FALSE)
