getwd()
setwd("~/git/LSHTM_analysis/mcsm_analysis/pyrazinamide/scripts/plotting")
getwd()

########################################################################
# 				Installing and loading required packages			   #	
########################################################################

source("../Header_TT.R")

#source("barplot_colour_function.R")

########################################################################
#		 Read file: call script for combining df for lig		   	   #
########################################################################

source("../combining_two_df_lig.R") 

#---------------------- PAY ATTENTION
# the above changes the working dir
#[1] "git/LSHTM_analysis/mcsm_analysis/pyrazinamide/scripts"
#---------------------- PAY ATTENTION

#==========================
# This will return:

# df with NA:
# merged_df2
# merged_df3

# df without NA:
# merged_df2_comp
# merged_df3_comp
#===========================

###########################
# Data for Lig Corr plots
# you need merged_df3_comp
# since these are matched 
# to allow pairwise corr
###########################

#<<<<<<<<<<<<<<<<<<<<<<<<<
# REASSIGNMENT
my_df  = merged_df3_comp 
#<<<<<<<<<<<<<<<<<<<<<<<<<

# delete variables not required
rm(merged_df2, merged_df2_comp, merged_df3, merged_df3_comp)

# quick checks
colnames(my_df)
str(my_df)

#############################
# Extra sanity check:
# for mcsm_lig ONLY
# Dis_lig_Ang should be <10
#############################

if (max(my_df$Dis_lig_Ang) < 10){
  print ("Sanity check passed: lig data is <10Ang")
}else{
  print ("Error: data should be filtered to be within 10Ang")
}

########################################################################
#               end of data extraction and cleaning for plots          #
########################################################################

#===========================
# Plot: Correlation plots
#===========================

#===================
# Data for plots
#===================

#<<<<<<<<<<<<<<<<<<<<<<<<
# REASSIGNMENT 
df  = my_df 
#<<<<<<<<<<<<<<<<<<<<<<<<<

rm(my_df)

# sanity checks
str(df)

table(df$Lig_outcome)

# unique positions
length(unique(df$Position)) #{RESULT: unique positions for comp data}

# subset data to generate pairwise correlations
corr_data = df[, c(#"ratioDUET",
                  "ratioPredAff"
#                  , "DUETStability_Kcalpermol"
#                  , "PredAffLog"
#                  , "OR"
                   , "logor"
#                  , "pvalue"
                   , "neglog10pvalue"
                   , "AF"
#                  , "DUET_outcome"
                   , "Lig_outcome"
                   , "pyrazinamide"
                   )] 
dim(corr_data)
rm(df)

# assign nice colnames (for display)
my_corr_colnames = c(#"DUET",
                     "Ligand Affinity"
#                    ,"DUET_raw" 
#                    , "Lig_raw"
#                    , "OR"
                     , "Log(Odds Ratio)"
#                    , "P-value"
                     , "-LogP"
                     , "Allele Frequency"
#                    , "DUET_outcome"
                     , "Lig_outcome"
                     , "pyrazinamide")
                     
# sanity check
if (length(my_corr_colnames) == length(corr_data)){
  print("Sanity check passed: corr_data and corr_names match in length")
}else{
  print("Error: length mismatch!")
}

colnames(corr_data)
colnames(corr_data) <- my_corr_colnames
colnames(corr_data)

###############
# PLOTS: corr
# http://www.sthda.com/english/wiki/scatter-plot-matrices-r-base-graphs
###############

# default pairs plot
start = 1
end = which(colnames(corr_data) == "pyrazinamide"); end # should be the last column
offset = 1

my_corr = corr_data[start:(end-offset)]
head(my_corr)

#my_cols = c("#f8766d", "#00bfc4")
# deep blue :#007d85
# deep red: #ae301e

#==========
# psych: ionformative since it draws the ellipsoid
# https://jamesmarquezportfolio.com/correlation_matrices_in_r.html
# http://www.sthda.com/english/wiki/scatter-plot-matrices-r-base-graphs
#==========

# set output dir for plots
getwd()
setwd("~/git/Data/pyrazinamide/output/plots"
getwd()

svg('Lig_corr.svg', width = 15, height = 15)
printFile = pairs.panels(my_corr[1:4]
             , method = "spearman" # correlation method
             , hist.col = "grey" ##00AFBB
             , density = TRUE  # show density plots
             , ellipses = F # show correlation ellipses
             , stars = T
             , rug = F
             , breaks = "Sturges"
             , show.points = T
             , bg = c("#f8766d", "#00bfc4")[unclass(factor(my_corr$Lig_outcome))]
             , pch = 21
             , jitter = T
#            , alpha = .05
#            , points(pch = 19, col = c("#f8766d", "#00bfc4"))
             , cex = 3
             , cex.axis = 2.5
             , cex.labels = 3
             , cex.cor = 1
             , smooth = F
)
print(printFile)
dev.off()

